"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseConfigErrors = exports.createEmbedConfigBasedOnEmbedType = exports.createTileConfig = exports.createDashboardConfig = exports.createReportConfig = exports.validateConfig = void 0;
var powerbi_client_1 = require("powerbi-client");
var index_1 = require("./index");
var pbi = __importStar(require("powerbi-client"));
var createReportConfig = function (props) {
    var tokenType = props.tokenType, accessToken = props.accessToken, embedUrl = props.embedUrl, embedId = props.embedId, permissions = props.permissions, pageName = props.pageName, extraSettings = props.extraSettings, datasetId = props.datasetId, reportMode = props.reportMode;
    if (reportMode === "Create") {
        return index_1.clean({
            type: 'report',
            tokenType: powerbi_client_1.models.TokenType[tokenType],
            accessToken: accessToken,
            embedUrl: embedUrl,
            datasetId: datasetId,
            reportMode: reportMode,
        });
    }
    var cleanSettings = index_1.clean(__assign({ filterPaneEnabled: true, navContentPaneEnabled: true }, extraSettings));
    var cleanDataSetBinding = index_1.clean({
        datasetId: datasetId,
    });
    var settings = index_1.isEmptyObject(cleanSettings)
        ? {}
        : {
            settings: cleanSettings,
        };
    var datasetBinding = index_1.isEmptyObject(cleanDataSetBinding)
        ? {}
        : {
            datasetBinding: cleanDataSetBinding,
        };
    return index_1.clean(__assign(__assign({ type: 'report', tokenType: powerbi_client_1.models.TokenType[tokenType], accessToken: accessToken,
        embedUrl: embedUrl, id: embedId, pageName: pageName, viewMode: powerbi_client_1.models.ViewMode[reportMode], permissions: powerbi_client_1.models.Permissions[permissions], reportMode: reportMode }, settings), datasetBinding));
};
exports.createReportConfig = createReportConfig;
var createDashboardConfig = function (props) {
    var tokenType = props.tokenType, accessToken = props.accessToken, embedUrl = props.embedUrl, pageView = props.pageView, embedId = props.embedId;
    return index_1.clean({
        type: 'dashboard',
        tokenType: powerbi_client_1.models.TokenType[tokenType],
        accessToken: accessToken,
        embedUrl: embedUrl,
        id: embedId,
        pageView: pageView,
    });
};
exports.createDashboardConfig = createDashboardConfig;
var createTileConfig = function (props) {
    var tokenType = props.tokenType, accessToken = props.accessToken, embedUrl = props.embedUrl, embedId = props.embedId, dashboardId = props.dashboardId;
    return index_1.clean({
        type: 'tile',
        tokenType: powerbi_client_1.models.TokenType[tokenType],
        accessToken: accessToken,
        embedUrl: embedUrl,
        id: embedId,
        dashboardId: dashboardId,
    });
};
exports.createTileConfig = createTileConfig;
var validateTypeConfig = function (config) {
    switch (config.type) {
        case 'report':
            return pbi.models.validateReportLoad(config);
        case 'dashboard':
            return pbi.models.validateDashboardLoad(config);
        case 'tile':
            return pbi.models.validateTileLoad(config);
        default:
            throw Error('Unknown config type allowed types are report, dashboard or tile');
    }
};
var validateCreateReportConfig = function (config) {
    if (!config.embedUrl)
        throw Error('Embed URL is required');
    return pbi.models.validateCreateReport(config);
};
var validateConfig = function (config) {
    var isCreateMode = config.reportMode === 'Create';
    return isCreateMode
        ? validateCreateReportConfig(config)
        : validateTypeConfig(config);
};
exports.validateConfig = validateConfig;
var createEmbedConfigBasedOnEmbedType = function (config) {
    var embedType = config.embedType;
    switch (embedType) {
        case 'report':
            return createReportConfig(config);
        case 'dashboard':
            return createDashboardConfig(config);
        case 'tile':
            return createTileConfig(config);
        default:
            throw Error('Wrong embed type!');
    }
};
exports.createEmbedConfigBasedOnEmbedType = createEmbedConfigBasedOnEmbedType;
var parseConfigErrors = function (errors) {
    var parsedError = '';
    if (Array.isArray(errors) && errors.length) {
        parsedError = errors
            .map(function (error) { return error.detailedMessage || error.message || ''; })
            .filter(function (x) { return x; })
            .join(', ');
    }
    return parsedError;
};
exports.parseConfigErrors = parseConfigErrors;
